@@ -1,22 +1,5 @@
-package Spark::Form::FAQ;
-our $VERSION = '0.0300';
-
-
-# ABSTRACT: Frequently Asked Questions about Spark::Form
-
 1;
-
-
-
-=pod
-
-=head1 NAME
-
-Spark::Form::FAQ - Frequently Asked Questions about Spark::Form
-
-=head1 VERSION
-
-version 0.0300
+__END__
 
 =head1 Frequently Asked Questions
 
@@ -25,8 +8,8 @@ version 0.0300
 None of the others met my needs. This is CPAN, people reinvent wheels
 properly so you don't have to.
 
-Essentially the only real viable alternative I've come across is HTML::FormFu
-and I wanted a Pure-Perl solution, no YAML.
+Essentially the only real viable alternative I've come across is HTML::FormFu 
+and I wanted a pure-perl solution, no YAML.
 
 =head2 Why Spark::Form?
 
@@ -60,33 +43,15 @@ No YAML files, no other language to learn. Just simple Perl.
 
 Easy to read and built with L<Moose> and L<Module::Pluggable>.
 
-=back 
+=back
 
 =head2 Why do you depend on Moose?
 
-It made writing this module a lot quicker and the code a lot cleaner. And it
+It made writing this module a lot quicker and the code a lot cleaner. And it 
 will make maintenance a lot easier.
 
 =head2 Will there be a non-Moose version?
 
 No. Feel free to create and maintain a fork.
 
-
-
-=head1 AUTHOR
-
-  James Laver L<http://jameslaver.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by James Laver C<< <sprintf qw(%s@%s.%s cpan jameslaver com)> >>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
-
-
-__END__
-
+=cut
