@@ -1,8 +1,4 @@
 package Spark::Form::Field::Role::Printable;
-our $VERSION = '0.0300';
-
-
-# ABSTRACT: Printability for form fields
 
 use Moose::Role;
 
@@ -13,19 +9,12 @@ has label => (
 );
 
 1;
-
-
-
-=pod
+__END__
 
 =head1 NAME
 
 Spark::Form::Field::Role::Printable - Printability for form fields
 
-=head1 VERSION
-
-version 0.0300
-
 =head1 DESCRIPTION
 
 A fairly free-form module, this is mostly used for checking that it's printable at all.
@@ -37,7 +26,7 @@ You probably want one of the roles under this hierarchy, but not just this one.
  use Moose;
  extends 'Spark::Form::Field';
  with 'Spark::Form::Field::Role::Printable';
-
+ 
  sub to_string {
      my $self = shift;
      sprintf("%s: %s",$self->label, $self->value);
@@ -54,22 +43,4 @@ A label that will be printed next to said field in the printed out version
 L<Spark::Form::Field::Printable::HTML> - Role for being printable under HTML4
 L<Spark::Form::Field::Printable::XHTML> - Role for being printable under XHTML1
 
-
-
-=head1 AUTHOR
-
-  James Laver L<http://jameslaver.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by James Laver C<< <sprintf qw(%s@%s.%s cpan jameslaver com)> >>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
-
-
-__END__
-
+=cut
\ No newline at end of file
